==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/pa/vpa81odext.c <==
/*!**********************************************************************

  module: vpa81odext.h

  -----------------------------------------------------------------------

  responsible:  

  special area: ODBC-Driver Extension

  description:  C wrapper functions for VB

  see also:     http://www.microsoft.com/data/odbc/

  -----------------------------------------------------------------------

  copyright:          Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/

/*=======================================================================
 *  INCLUDES
 *=====================================================================*/

#include "hpa81odext.h"


SQLRETURN WINAPI pa81SetStrStmtOption( SQLHSTMT     hstmt,
                                       SQLUSMALLINT option,
                                       SQLPOINTER   value)
{
    return SQLSetStmtOption( hstmt, option, (UDWORD) value );
} /* pa81SetStrStmtOption */


SQLRETURN WINAPI pa81SetStrConnectOption( SQLHSTMT     hstmt,
                                          SQLUSMALLINT option,
                                          SQLPOINTER   value)
{
    return SQLSetConnectOption( hstmt, option, (UDWORD) value );
} /* pa81SetStrStmtOption */


SQLRETURN WINAPI pa81GetStrConnectOption( SQLHSTMT     hstmt,
                                          SQLUSMALLINT option,
                                          SQLPOINTER   value)
{
    return SQLGetConnectOption( hstmt, option, value );
} /* pa81SetStrStmtOption */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/pa/vpa81odext.c <==
/*!**********************************************************************

  module: vpa81odext.h

  -----------------------------------------------------------------------

  responsible:  

  special area: ODBC-Driver Extension

  description:  C wrapper functions for VB

  see also:     http://www.microsoft.com/data/odbc/

  -----------------------------------------------------------------------

  copyright:          Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/

/*=======================================================================
 *  INCLUDES
 *=====================================================================*/

#include "hpa81odext.h"


SQLRETURN WINAPI pa81SetStrStmtOption( SQLHSTMT     hstmt,
                                       SQLUSMALLINT option,
                                       SQLPOINTER   value)
{
    return SQLSetStmtOption( hstmt, option, (SQLROWCOUNT) value );
} /* pa81SetStrStmtOption */


SQLRETURN WINAPI pa81SetStrConnectOption( SQLHSTMT     hstmt,
                                          SQLUSMALLINT option,
                                          SQLPOINTER   value)
{
    return SQLSetConnectOption( hstmt, option, (SQLROWCOUNT) value );
} /* pa81SetStrStmtOption */


SQLRETURN WINAPI pa81GetStrConnectOption( SQLHSTMT     hstmt,
                                          SQLUSMALLINT option,
                                          SQLPOINTER   value)
{
    return SQLGetConnectOption( hstmt, option, value );
} /* pa81SetStrStmtOption */
